parse_book_snapshot_msg_as_quote

Function parse_book_snapshot_msg_as_quote 

pub fn parse_book_snapshot_msg_as_quote(
    msg: BookSnapshotMsg,
    price_precision: u8,
    size_precision: u8,
    instrument_id: InstrumentId,
) -> Result<QuoteTick>
Parse a book snapshot message into a quote tick, returning an error on invalid data. Parse a book snapshot message into a quote tick.

Errors

Returns an error if missing bid/ask levels or invalid sizes.